# OpenICC Profiles

These profiles are here for testing, are are originally from the OpenICC project.

Sources can be found: https://sourceforge.net/projects/openicc/files/OpenICC-Profiles/

The icc can be generated from the sources using this command:

  colprof FOGRA30L.ti3 FOGRA30L.icc

It may take some time to complete.

# Copyright

Copyright (c) 2008-2011 Kai-Uwe Behrmann
BSD-2 License, see original sources for details.
